![sek](images/sek.png)

Runtime Cloud Security Scanning.

# Status
Concept / Dev / Test / Pre-pre-release. Just trying some things and working out how stuff might fit together.


# Overview
TODO


# Checks
Organisation, structure, content, reasoning and support information for all Checks in Sek.

[checks/readme.md](checks/readme.md)

**Example: AWS - EKS**

[checks/aws/eks/readme.md](checks/aws/eks/readme.md)


# Use

## Install
```
pip3 install sek
```

## Configure
TODO

## Run
```
# Example
sek --cloud=aws --resource=eks --name=test
```


# Contributing
[contributing.md](contributing.md)
